import { defineMessages } from 'react-intl';

const template = (configContext) => {
  const {
    React,
  } = configContext.lib;

  const {
    CompoundInput,
  } = configContext.inputComponents;

  const {
    Col,
    Cols,
    Panel,
    Row,
  } = configContext.layoutComponents;

  const {
    Field,
    InputTable,
  } = configContext.recordComponents;

  const {
    extensions,
  } = configContext.config;

  return (
    <Field name="document">
      <Panel name="id" collapsible>
        <Row>
          <Col>
            <Field name="objectNumber" label="Inventory No [Identification number]" />
            <Field name="numberOfObjects" label="Count [Number of objects]"/>
            
            <Field name="catalogLevel" subpath="ns2:collectionobjects_fineart" label="Catalog level [Cataloging level]" />

            <Field name="otherNumberList">
              <Field name="otherNumber">
                <Field name="numberValue" />
                <Field name="numberType" />
              </Field>
            </Field>

            <Field name="responsibleDepartments">
              <Field name="responsibleDepartment" />
            </Field>

            <Field name="collection" />

            <Field name="recordStatus" />

            <Field name="inventoryStatusList">
              <Field name="inventoryStatus" />
            </Field>

            <Field name="publishToList">
              <Field name="publishTo" />
            </Field>
 
          </Col>

          <Col>
            <Field name="briefDescriptions">
              <Field name="briefDescription" label="Description [Brief description]"/>
            </Field>

            <Field name="comments">
              <Field name="comment" label="Created By/Date/ID [Comment]"/>
            </Field>

            <Field name="computedCurrentLocation" />
          </Col>
        </Row>

        <Field name="titleGroupList">
          <Field name="titleGroup">
            <Panel>
              <Row>
                <Col>
                  <Field name="title" label="Object Title/Type [Title]"/>
                  
                </Col>

                <Col>
                  <Field name="titleLanguage" />

                  <Field name="titleTranslationSubGroupList">
                    <Field name="titleTranslationSubGroup">
                      <Field name="titleTranslation" />
                      <Field name="titleTranslationLanguage" />
                    </Field>
                  </Field>
                </Col>
              </Row>
            </Panel>
          </Field>
        </Field>

        <Field name="objectNameList">
          <Field name="objectNameGroup">
            <Field name="objectName" />
            <Field name="objectNameLevel" />
            <Field name="objectNameType" />
          </Field>
        </Field>
      </Panel>

      <Panel name="prod" collapsible collapsed>
        <Row>
          <Col>
            <Field name="objectProductionDateGroupList">
              <Field name="objectProductionDateGroup" label="Object Date and Period [Production date]"/>
            </Field>

            {/* <Field name="techniqueGroupList">
              <Field name="techniqueGroup">
                <Field name="technique" />
              </Field>
            </Field> */}

            <Field name="objectProductionPlaceGroupList">
              <Field name="objectProductionPlaceGroup" label="Place of Origin [Production place]">
                <Field name="objectProductionPlace" />
                <Field name="objectProductionPlaceRole" />
              </Field>
            </Field>
          </Col>

          <Col>
            <Field name="objectProductionPersonGroupList">
              <Field name="objectProductionPersonGroup" label="Artist/Maker [Production person]">
                <Field name="objectProductionPerson" />
                <Field name="objectProductionPersonRole"/>
              </Field>
            </Field>

            <Field name="objectProductionNote" />
          </Col>
        </Row>
      </Panel>

      <Panel name="desc" collapsible collapsed>
        <Row>
          <Col>
            <Field name="copyNumber" label="Copy/Series No. [Copy number]"/>
          </Col>
        </Row>

        <Field name="materialTechniqueDescription" subpath="ns2:collectionobjects_fineart" label="Medium/technique description [Material/technique description]"/>

        {/*change position from object production information*/}
        <Field name="techniqueGroupList">  
              <Field name="techniqueGroup" label="Technique [Production technique]">
                <Field name="technique" />
              </Field>
        </Field>

        <Field name="materialGroupList">
          <Field name="materialGroup" label="Medium [Material]">
            <Field name="material" />
            <Field name="materialComponent" />
            <Field name="materialComponentNote" />
            <Field name="materialName" />
            <Field name="materialSource" />
          </Field>
        </Field>

        <Field name="physicalDescription" label="Conservetion condition [Physical description]"/>

        <Row>
          <Col>
            <Field name="objectComponentGroupList">
              <Field name="objectComponentGroup" label="Accessory [Object component]">
                <Field name="objectComponentName" />
                <Field name="objectComponentInformation" />
              </Field>
            </Field>
          </Col>
        </Row>

        {extensions.dimension.form}

        <Panel name="content" collapsible collapsed>
          <Field name="contentDescription" />

          <Row>
            <Col>
              <Field name="contentLanguages">
                <Field name="contentLanguage" />
              </Field>

              <Field name="contentActivities">
                <Field name="contentActivity" />
              </Field>

              <Field name="contentConcepts">
                <Field name="contentConcept" />
              </Field>

              <Field name="contentDateGroup" />

              <Field name="contentPositions">
                <Field name="contentPosition" />
              </Field>

              <Field name="contentObjectGroupList">
                <Field name="contentObjectGroup">
                  <Field name="contentObject" />
                  <Field name="contentObjectType" />
                </Field>
              </Field>
            </Col>

            <Col>
              <Field name="contentPeoples">
                <Field name="contentPeople" />
              </Field>

              <Field name="contentPersons">
                <Field name="contentPerson" />
              </Field>

              <Field name="contentPlaces">
                <Field name="contentPlace" />
              </Field>

              <Field name="contentScripts">
                <Field name="contentScript" />
              </Field>

              <Field name="contentOrganizations">
                <Field name="contentOrganization" />
              </Field>

              <Field name="contentEventNameGroupList">
                <Field name="contentEventNameGroup">
                  <Field name="contentEventName" />
                  <Field name="contentEventNameType" />
                </Field>
              </Field>

              <Field name="contentOtherGroupList">
                <Field name="contentOtherGroup">
                  <Field name="contentOther" />
                  <Field name="contentOtherType" />
                </Field>
              </Field>
            </Col>
          </Row>

          <Field name="contentNote" />

          <Row>
            <CompoundInput subpath="ns2:collectionobjects_variablemedia">
              {extensions.contentWorks.form}
            </CompoundInput>
          </Row>
        </Panel>

        <Panel name="textInscript" collapsible collapsed>
          <Field name="textualInscriptionGroupList">
            <Field name="textualInscriptionGroup">
              <Panel>
                <Field name="inscriptionContent" label="Signature/Inscription [Inscription content]"/>

                <Field name="inscriptionContentInterpretation" label="Interpretation/Translation [Interpretation]"/>
              </Panel>
            </Field>
          </Field>
        </Panel>

      </Panel>

      {/* <Panel name="technicalSpecs" collapsible collapsed>
        <CompoundInput subpath="ns2:collectionobjects_variablemedia">
          {extensions.technicalSpecs.form}
        </CompoundInput>
      </Panel> */}

      <Panel name="hist" collapsible collapsed>
        <Panel name="assoc" collapsible collapsed>
          <Row>
            <Col>
              <Field name="assocActivityGroupList">
                <Field name="assocActivityGroup">
                  <Field name="assocActivity" />
                  <Field name="assocActivityType" />
                  <Field name="assocActivityNote" />
                </Field>
              </Field>

              <Field name="assocObjectGroupList">
                <Field name="assocObjectGroup">
                  <Field name="assocObject" />
                  <Field name="assocObjectType" />
                  <Field name="assocObjectNote" />
                </Field>
              </Field>

              <Field name="assocConceptGroupList">
                <Field name="assocConceptGroup">
                  <Field name="assocConcept" />
                  <Field name="assocConceptType" />
                  <Field name="assocConceptNote" />
                </Field>
              </Field>

              <Field name="assocCulturalContextGroupList">
                <Field name="assocCulturalContextGroup">
                  <Field name="assocCulturalContext" />
                  <Field name="assocCulturalContextType" />
                  <Field name="assocCulturalContextNote" />
                </Field>
              </Field>

              <Field name="assocOrganizationGroupList">
                <Field name="assocOrganizationGroup">
                  <Field name="assocOrganization" />
                  <Field name="assocOrganizationType" />
                  <Field name="assocOrganizationNote" />
                </Field>
              </Field>

              <Field name="assocPeopleGroupList">
                <Field name="assocPeopleGroup">
                  <Field name="assocPeople" />
                  <Field name="assocPeopleType" />
                  <Field name="assocPeopleNote" />
                </Field>
              </Field>

              <Field name="assocPersonGroupList">
                <Field name="assocPersonGroup">
                  <Field name="assocPerson" />
                  <Field name="assocPersonType" />
                  <Field name="assocPersonNote" />
                </Field>
              </Field>

              <Field name="assocPlaceGroupList">
                <Field name="assocPlaceGroup">
                  <Field name="assocPlace" />
                  <Field name="assocPlaceType" />
                  <Field name="assocPlaceNote" />
                </Field>
              </Field>
            </Col>

            <Col>
              <InputTable name="assocEvent">
                <Field name="assocEventName" />
                <Field name="assocEventNameType" />
              </InputTable>

              <Field name="assocEventOrganizations">
                <Field name="assocEventOrganization" />
              </Field>

              <Field name="assocEventPeoples">
                <Field name="assocEventPeople" />
              </Field>

              <Field name="assocEventPersons">
                <Field name="assocEventPerson" />
              </Field>

              <Field name="assocEventPlaces">
                <Field name="assocEventPlace" />
              </Field>

              <Field name="assocEventNote" />

              <Field name="assocDateGroupList">
                <Field name="assocDateGroup">
                  <Field name="assocStructuredDateGroup" />
                  <Field name="assocDateType" />
                  <Field name="assocDateNote" />
                </Field>
              </Field>
            </Col>
          </Row>
        </Panel>

        <Field name="objectHistoryNote" label="Object History [Object history note]"/>

        <Field name="usageGroupList" label="Object history/Provenance note [Usage]">
          <Field name="usageGroup">
            <Field name="usage" />
            <Field name="usageNote" />
          </Field>
        </Field>

        <Row>
          <Col>

            <Field name="ownershipDateGroupList">
              <Field name="ownershipDateGroup" label="Acquisition date [Ownership date]"/>
            </Field>
          </Col>

          <Col>
            <Row>
              <Field name="ownershipCategory" label="Acquisition method [Ownership category]"/>
            </Row>
          </Col>
        </Row>

        <InputTable name="ownershipExchange">
          <Field name="ownershipExchangeNote" />
          <Field name="ownershipExchangePriceCurrency" />
          <Field name="ownershipExchangePriceValue" />
        </InputTable>
      </Panel>

      <Panel name="reference" collapsible collapsed>
        <Field name="referenceGroupList">
          <Field name="referenceGroup" label="Publications [Reference]">
            <Field name="reference"/>
            <Field name="referenceNote" />
          </Field>
        </Field>
      </Panel>

      <Panel name="viewer" collapsible collapsed>
        <Field name="viewersReferences">
          <Field name="viewersReference" />
        </Field>

        <Field name="viewersContributionNote" />
      </Panel>

      <Panel name="rights" collapsible collapsed>
        <Field name="rightsGroupList">
          <Field name="rightsGroup">
            <Panel>
              <Row>
                <Field name="rightType" />

                <Row>
                  <Field name="rightBeginDate" />
                  <Field name="rightEndDate" />
                </Row>
              </Row>

              <Field name="rightHolderGroupList">
                <Field name="rightHolderGroup">
                  <Field name="rightHolder" />
                  <Field name="rightHolderContact" />
                </Field>
              </Field>

              <Row>
                <Field name="rightJurisdiction" />
                <Field name="standardizedRightStatement" />
              </Row>

              <Field name="rightStatement" />
              <Field name="rightNote" />
            </Panel>
          </Field>
        </Field>
      </Panel>

      <Panel name="rightsin" collapsible collapsed>
        <Field name="rightsInGroupList">
          <Field name="rightsInGroup">
            <Panel>
              <Row>
                <Field name="rightInTypes">
                  <Field name="rightInType" />
                </Field>

                <Row>
                  <Field name="rightInBeginDate" />
                  <Field name="rightInEndDate" />
                </Row>
              </Row>

              <Row>
                <Field name="agreementSent" />
                <Field name="agreementReceived" />
                <Field name="agreementSigned" />
              </Row>

              <Cols>
                <Col>
                  <Field name="rightInRestrictions">
                    <Field name="rightInRestriction" />
                  </Field>
                </Col>

                <Col>
                  <Field name="rightReproductionStatement" />
                </Col>
              </Cols>

              <Field name="rightInNote" />
            </Panel>
          </Field>
        </Field>
      </Panel>

      <Panel name="hierarchy" collapsible collapsed>
        <Field name="relation-list-item" subpath="rel:relations-common-list" />
      </Panel>
    </Field>
  );
};

export default (configContext) => ({
  messages: defineMessages({
    name: {
      id: 'form.collectionobjec.hku.name',
      defaultMessage: 'HKU Template: UMAG',
    },
  }),
  sortOrder: 0,
  template: template(configContext),
});
